@@ -1,6 +1,3 @@
-
-
-
 from pyspedas import tnames
 from pytplot import options
 
@@ -8,7 +5,8 @@ def mms_eis_set_metadata(tplotnames, data_rate='srvy', datatype='extof', suffix=
     """
     This function updates the metadata for the EIS data products
     
-    Parameters:
+    Parameters
+    ----------
         tplotnames : list of str
             list of tplot variables loaded by the load routine
 
@@ -25,5 +23,12 @@ def mms_eis_set_metadata(tplotnames, data_rate='srvy', datatype='extof', suffix=
     """
     if datatype == 'extof':
         options(tnames('*_extof_proton_flux_omni*'), 'yrange', [55, 1000])
-        options(tnames('*_extof_alpha_flux_omni*'), 'yrange', [80, 650])
+        # options(tnames('*_extof_alpha_flux_omni*'), 'yrange', [80, 650]) # removed in the latest files as of 3 Aug 2021
+        options(tnames('*_extof_helium_flux_omni*'), 'yrange', [80, 650])
         options(tnames('*_extof_oxygen_flux_omni*'), 'yrange', [145, 950])
+        options(tnames('*_extof_proton_flux_omni*'), 'x_interp', True)
+        options(tnames('*_extof_proton_flux_omni*'), 'y_interp', True)
+        options(tnames('*_extof_helium_flux_omni*'), 'x_interp', True)
+        options(tnames('*_extof_helium_flux_omni*'), 'y_interp', True)
+        options(tnames('*_extof_oxygen_flux_omni*'), 'x_interp', True)
+        options(tnames('*_extof_oxygen_flux_omni*'), 'y_interp', True)
\ No newline at end of file
