@@ -10,7 +10,7 @@ def plot(the_slice,
          xrange=None,
          yrange=None,
          zrange=None,
-         colormap='spedas',
+         colormap=None,
          olines=8,
          contours=False,
          plotsize=10,
@@ -36,6 +36,14 @@ def plot(the_slice,
     else:
         spec_options['norm'] = mpl.colors.LogNorm(vmin=zrange[0], vmax=zrange[1])
 
+    style = pytplot.tplot_opt_glob.get('style')
+
+    if style is None:
+        if colormap is None:
+            colormap = 'spedas'
+    else:
+        plt.style.use(style)
+
     if colormap == 'spedas':
         _colors = pytplot.spedas_colorbar
         spd_map = [(np.array([r, g, b])).astype(np.float64) / 256 for r, g, b in zip(_colors.r, _colors.g, _colors.b)]
@@ -45,6 +53,10 @@ def plot(the_slice,
 
     spec_options['cmap'] = cmap
 
+    char_size = pytplot.tplot_opt_glob.get('charsize')
+    if char_size is None:
+        char_size = 12
+
     fig, axes = plt.subplots()
     fig.set_size_inches(plotsize, plotsize)
 
@@ -54,11 +66,17 @@ def plot(the_slice,
     if yrange is not None:
         axes.set_ylim(yrange)
 
+    axis_font_size = pytplot.tplot_opt_glob.get('axis_font_size')
+
+    if axis_font_size is not None:
+        axes.tick_params(axis='x', labelsize=axis_font_size)
+        axes.tick_params(axis='y', labelsize=axis_font_size)
+
     info = slice2d_getinfo(the_slice)
 
-    axes.set_title(info['title'])
-    axes.set_ylabel(info['ytitle'])
-    axes.set_xlabel(info['xtitle'])
+    axes.set_title(info['title'], fontsize=char_size)
+    axes.set_ylabel(info['ytitle'], fontsize=char_size)
+    axes.set_xlabel(info['xtitle'], fontsize=char_size)
 
     fig.subplots_adjust(left=0.14, right=0.86, top=0.86, bottom=0.14)
 
@@ -66,11 +84,14 @@ def plot(the_slice,
     pad, width = 0.02, 0.01
     cax = fig.add_axes([box.xmax + pad, box.ymin, width, box.height])
 
+    if axis_font_size is not None:
+        cax.tick_params(labelsize=axis_font_size)
+
     im = axes.pcolormesh(the_slice['xgrid'], the_slice['ygrid'], the_slice['data'].T, **spec_options)
 
     colorbar = fig.colorbar(im, cax=cax)
 
-    colorbar.set_label(info['ztitle'])
+    colorbar.set_label(info['ztitle'], fontsize=char_size)
 
     # draw lines at the origin
     axes.axvline(x=0, linestyle=(0, (5, 10)), color='black')
